dansk.py
========

Python, but danish.


Installering
------------

For at installere ``dansk.py``, skal du køre: ::

    $ pip install dansk


Anvendelse
----------

Alt bliver godt, hvis du skriver ``# coding=dansk`` på den første
linje i din kode.
